<?php

require_once __DIR__."/listing.php";
if (file_exists(__DIR__."/admin_pro.php"))
  include_once __DIR__."/admin_pro.php";
  
////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Add options needed for plugin

add_option('fubaby_ebayCampaignID', ''); //The ebay campaign id.
add_option('fubaby_ebayDefCustomID', ''); //The ebay custom id.
add_option('fubaby_ebayGlobalID', 'EBAY-GB'); // Ebay Global ID.
add_option('fubaby_ebayDefCategory', ''); // Default category ids. 
add_option('fubaby_ebayDefSeller', ''); // Default seller. 
add_option('fubaby_ebayDefColumns', 2); // Default columns of search results.
add_option('fubaby_ebayDefRows', 1); // Default rows of search results.
add_option('fubaby_ebayDefSort', 'BestMatch'); // Default sort order of search results
add_option('fubaby_ebayPicWidthItem', 225); // Default width of pictures.
add_option('fubaby_ebayPicWidthList', 225); // Default width of pictures.
add_option('fubaby_ebayDefArrangementItem', fuEbayArrangement::ImageLeft); // Default arrangement for single items.
add_option('fubaby_ebayDefArrangementList', 0); // Default arrangement for search listings.
add_option('fubaby_ebayDefArrangementWidget', 0); // Default arrangement for widgets.
add_option('fubaby_ebayDefSlideshowStyle', "Manual"); // Default slideshow style
add_option('fubaby_ebayDefNumSlides', 3); // Default number of slideshow slides
add_option('fubaby_ebayEmptySearchMsg', 'No items found.'); // Default empty results message.
add_option('fubaby_ebayNewWindow', 1); // Whether to open ebay links in new window/tab.
add_option('fubaby_ebayDeferredLoading', "NotCached"); // Whether to open ebay links in new window/tab.
add_option('fubaby_ebaySubscriptionKey', ""); // Key for subscription.

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Remove options on uninstall.

function fu_ebay_uninstall()
{
  delete_option('fubaby_ebayPublisherID');
  delete_option('fubaby_ebayCampaignID');
  delete_option('fubaby_ebayGlobalID');
  delete_option('fubaby_ebayDefCustomID');
  delete_option('fubaby_ebayDefCategory');
  delete_option('fubaby_ebayDefSeller');
  delete_option('fubaby_ebayDefColumns');
  delete_option('fubaby_ebayDefRows');
  delete_option('fubaby_ebayDefSort');
  delete_option('fubaby_ebayGeoTarget');
  delete_option('fubaby_ebayPicWidthItem');
  delete_option('fubaby_ebayPicWidthList');
  delete_option('fubaby_ebayDefArrangementItem');
  delete_option('fubaby_ebayDefArrangementList');
  delete_option('fubaby_ebayDefArrangementWidget');
  delete_option('fubaby_ebayDefSlideshowStyle');
  delete_option('fubaby_ebayDefNumSlides');
  delete_option('fubaby_ebayEmptySearchMsg');
  delete_option('fubaby_ebayNewWindow');
  delete_option('fubaby_ebayDeferredLoading');
  delete_option('fubaby_ebaySubscriptionKey', "");
 
  // Bring in Pro features
  if (function_exists("fu_ebaypro_uninstall"))
    fu_ebaypro_uninstall();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Admin page user interface

add_action('admin_menu', 'fu_ebay_menu');

function fu_ebay_menu() 
{
  
  add_options_page(
    "Fast eBay Listings " . __("Options", "fast-ebay-listings"), 
    'Fast eBay Listings', 
    'manage_options', 
    __FILE__, 
    function_exists('fu_ebaypro_options') ? 'fu_ebaypro_options' : 'fu_ebay_options');
	add_action( 'admin_init', 'fu_ebay_register_settings' );
}

///////////////////////////////////////////////////////////////////////////////////////
// Begin general options

function fu_ebay_register_settings()
{
  // First, we register a section. This is necessary since all future options must belong to one.
  add_settings_section(
      'fu_ebay_settings_section_general',         // ID used to identify this section and with which to register options
      __("General Options", "fast-ebay-listings"),                  // Title to be displayed on the administration page
      'fu_ebay_options_callback', // Callback used to render the description of the section
      'fu_ebay_options_general'   // Page on which to add this section of options
      );
   
  add_settings_field(
      'fubaby_ebayGlobalID',
      __('eBay Global Id', "fast-ebay-listings"),
      'fu_ebay_globalid_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_general',
      array(
          'id' => 'fubaby_ebayGlobalID',
          'label' => __('eBay site to perform searches on', "fast-ebay-listings")
      )
      );
  
  // Defaults Section
  add_settings_section(
      'fu_ebay_settings_section_defaults',
      __("Default Options", "fast-ebay-listings"),
      'fu_ebay_options_callback',
      'fu_ebay_options_general'
      );
  
  add_settings_field(
      'fubaby_ebayDefCategory',
      __('Default Category Id', "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefCategory',
          'label' => __('Used for search results when no category is specified. Comma separated list of id\'s, three  max.', "fast-ebay-listings")
      )
      );
  add_settings_field(
      'fubaby_ebayDefSeller',
      __('Default Seller Id(s)', "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefSeller',
          'label' => __("Used for search results when no seller is specified (comma separated list). <br/>" .
              "Special key values:<br/><ul>".
              "<li>'all' - (or left blank) to default to all sellers.</li>" .
              "<li>'author' - Use eBay username set on post author's profile.</li></ul>", 
              "fast-ebay-listings")
      )
      );
  add_settings_field(
      'fubaby_ebayDefColumns',
      __('Default Search Results Columns', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefColumns',
          'label' => __('Default number of columns to split search results into.', "fast-ebay-listings")
      )
      );  
  add_settings_field(
      'fubaby_ebayDefRows',
      __('Default Search Results Rows', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefRows',
          'label' => __('Default number of rows to split search results into.', "fast-ebay-listings")
      )
      ); 
  add_settings_field(
      'fubaby_ebayDefSlideshowStyle',
      __('Default Slideshow Style', "fast-ebay-listings"),
      'fu_ebay_slideshowstyle_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefSlideshowStyle',
          'label' => __('Default slideshow style: when slideshow="default" on shortcodes.', "fast-ebay-listings")
      )
      );
  add_settings_field(
      'fubaby_ebayDefNumSlides',
      __('Default Slides', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefNumSlides',
          'label' => __('Default number of slideshow slides.', "fast-ebay-listings")
      )
      );  
   add_settings_field(
      'fubaby_ebayDefSort',
      __('Default Search Results Sorting', "fast-ebay-listings"),
      'fu_ebay_sortorder_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_defaults',
      array(
          'id' => 'fubaby_ebayDefSort',
          'label' => __('Default sort order of search results.', "fast-ebay-listings")
      )
      );
  
  // Behaviour Section
  add_settings_section(
      'fu_ebay_settings_section_behaviour',
      __("Behaviour Options", "fast-ebay-listings"),
      'fu_ebay_options_callback',
      'fu_ebay_options_general'
      );
  

  add_settings_field(
      'fubaby_ebayPicWidthItem',
      __('Default eBay Item Picture Width', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayPicWidthItem',
          'label' => __('Default width of thumbnails for single items shortcode.', "fast-ebay-listings")
      )
      );  
  add_settings_field(
      'fubaby_ebayPicWidthList',
      __('Default eBay Search Listings Picture Width', "fast-ebay-listings"),
      'fu_ebay_intinput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayPicWidthList',
          'label' => __('Default width of thumbnails for search listings shortcode.', "fast-ebay-listings")
      )
      );  
  add_settings_field(
      'fubaby_ebayDefArrangementItem',
      __('Default eBay Item Arrangement', "fast-ebay-listings"),
      'fu_ebay_arrangement_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayDefArrangementItem',
          'label' => __('Default Arrangement for single item shortcode.', "fast-ebay-listings")
      )
      );  
  add_settings_field(
      'fubaby_ebayDefArrangementList',
      __('Default eBay Search Listings Arrangement', "fast-ebay-listings"),
      'fu_ebay_arrangement_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayDefArrangementList',
          'label' => __('Default Arrangement for search listings and RSS feed shortcodes', "fast-ebay-listings")
      )
      );
  add_settings_field(
      'fubaby_ebayDefArrangementWidget',
      __('Default eBay Widget Arrangement', "fast-ebay-listings"),
      'fu_ebay_arrangement_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayDefArrangementWidget',
          'label' => __('Default Arrangement for widgets', "fast-ebay-listings")
      )
      );
  add_settings_field(
      'fubaby_ebayEmptySearchMsg',
      __('Empty search results message', "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayEmptySearchMsg',
          'label' => __('Displayed when an ebay search returns no results.', "fast-ebay-listings"),
          'width' => '50%'
      )
      );
  add_settings_field(
      'fubaby_ebayNewWindow',
      __('Open in new window', "fast-ebay-listings"),
      'fu_ebay_checkbox_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayNewWindow',
          'label' => __('If ticked, eBay links will open in a new browser tab/window.', "fast-ebay-listings"),
      )
      ); 
  add_settings_field(
      'fubaby_ebayDeferredLoading',
      __('Deferred loading of listings', "fast-ebay-listings"),
      'fu_ebay_deferredloading_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_behaviour',
      array(
          'id' => 'fubaby_ebayDeferredLoading',
          'label' => __('Defer loading of eBay listings to improve page load times', "fast-ebay-listings")
      )
      );

  // EPN Section
  add_settings_section(
      'fu_ebay_settings_section_epn',
      __("eBay Partner Network Options", "fast-ebay-listings"),
      'fu_ebay_options_callback_epn',
      'fu_ebay_options_general'
      );
  
  add_settings_field(
      'fubaby_ebayCampaignID',
      __('Affiliate Campaign Id', "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_epn',
      array(
          'id' => 'fubaby_ebayCampaignID',
          'label' => __('10 digit EPN campaign id.', "fast-ebay-listings"),
          'pattern' => '[0-9]{10}'
      )
    );

  add_settings_field(
      'fubaby_ebayDefCustomID',
      __('Default Affiliate Custom Id', "fast-ebay-listings"),
      'fu_ebay_definput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_epn',
      array(
          'id' => 'fubaby_ebayDefCustomID',
          'label' => __('Default custom tracking id to aid monitoring in EPN.', "fast-ebay-listings")
      )
    );         
  
  add_settings_field(
      'fubaby_ebaySubscriptionKey',
      'Subscription Key',
      'fu_ebay_definput_callback',
      'fu_ebay_options_general',
      'fu_ebay_settings_section_epn',
      array(
          'id' => 'fubaby_ebaySubscriptionKey',
          'label' => 'Fast eBay Listings subscription service coming soon!',
          'width' => '50%'
      )
      );

  // register our settings
  register_setting('fu_ebay_settings_group', 'fubaby_ebayCampaignID');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayGlobalID');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefCustomID');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefCategory');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefSeller');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefColumns');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefRows');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefSort');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayPicWidthItem');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayPicWidthList');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefArrangementItem');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefArrangementList');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefArrangementWidget');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefSlideshowStyle');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDefNumSlides');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayEmptySearchMsg');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayNewWindow');
  register_setting('fu_ebay_settings_group', 'fubaby_ebayDeferredLoading');
  register_setting('fu_ebay_settings_group', 'fubaby_ebaySubscriptionKey');

   // Bring in Pro features
  if (function_exists("fu_ebaypro_register_settings"))
    fu_ebaypro_register_settings();
}

function fu_ebay_options_callback()
{
}

function fu_ebay_options_callback_epn()
{
  echo "<p>If you are signed up for the eBay Partner Network and wish to monitise your eBay links
fill in your details here.</p>";

  if (!function_exists('fu_ebaypro_options'))
  {
    echo "<p>The free version of " . FUBABY_EBAY_PLUGIN_TITLE . " will assign 50% of eBay links to 
  the plugin developer to help maintain and support the plugin's development.</p>";
  }
}

function fu_ebay_options()
{
  if (!current_user_can('manage_options'))  {
    wp_die( __('You do not have sufficient permissions to access this page.') );
  }  

  $logoCompatAppUrl = plugins_url(basename(__DIR__) . "/images/compatibleapplication.gif");  
  $bannerUrl = plugins_url(basename(__DIR__) . "/images/banner-772x250.jpg");  
  
  ?>
<div class="wrap">
  <h1>Fubaby <?php echo FUBABY_EBAY_PLUGIN_TITLE; ?> - Free Version</h1>
  <div style="float:right">
  <img src="<?php echo $logoCompatAppUrl; ?>" width="108" height="64" border="0" style="padding: 10px; background: #fff;" />
  </div>
  <img src="<?php echo $bannerUrl; ?>" width="772" height="250" border="0">
  <p><a href="https://www.fubaby.com/wordpress-plugins/fast-ebay-listings/" target="_blank">Further documentation and info can be found here</a></p>

  <!-- Create the form that will be used to render our options -->  
  <form method="post" action="options.php">  
    <?php 
    settings_fields( 'fu_ebay_settings_group' ); 
    ?>  
    <?php do_settings_sections( 'fu_ebay_options_general' ); ?>             
    <?php submit_button(); ?>  
  </form>  
  
  <p>Fubaby <?php echo FUBABY_EBAY_PLUGIN_TITLE; ?> is a member of the eBay Developer Program and is a certified application. It is not associated with eBay in any way. 
  </p>
</div>
<?php
}


function fu_ebay_definput_callback($args)
{
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $width = isset($args['width']) ? 'style="width:'.$args['width'].';"' : "";
  $pattern = isset($args['pattern']) ? 'pattern="'.$args['pattern'].'"' : "";
  $html = '<input type="text" id="'.$args['id'].'" name="'.$args['id'].'" value="'.get_option($args['id']).'" '.$width.' '.$pattern.'/>';
  $html .= fu_ebay_addformlabel($args);
  echo $html;
}
function fu_ebay_intinput_callback($args)
{
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $width = isset($args['width']) ? 'style="width:'.$args['width'].';"' : "";
  $min = isset($args['min']) ? 'min="'.$args['min'].'"' : "";
  $max = isset($args['max']) ? 'max="'.$args['max'].'"' : "";
  $html = '<input type="number" id="'.$args['id'].'" name="'.$args['id'].'" value="'.get_option($args['id']).'" '.$width.' '.$min.' '.$max.'/>';
  $html .= fu_ebay_addformlabel($args);
  echo $html;
}
function fu_ebay_checkbox_callback($args)
{
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $html = '<input type="checkbox" id="'.$args['id'].'" name="'.$args['id'].'"'. checked(true, get_option($args['id']), false) . ' value="1" />';
  $html .= fu_ebay_addformlabel($args);
  echo $html;
}
function fu_ebay_textarea_callback($args) 
{    
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field  
  $html = '<textarea cols="80" rows="'.(isset($args['rows']) ? $args['rows'] : 4).'" id="'.$args['id'].'" name="'.$args['id'].'">'.get_option($args['id']).'</textarea>';
  $html .= fu_ebay_addformlabel($args);
  echo $html;  
}
function fu_ebay_url_callback($args)
{
  // Note the ID and the name attribute of the element should match that of the ID in the call to add_settings_field
  $width = isset($args['width']) ? 'style="width:'.$args['width'].';"' : "";
  $html = '<input type="url" id="'.$args['id'].'" name="'.$args['id'].'" value="'.get_option($args['id']).'" '.$width.'/>';
  $html .= fu_ebay_addformlabel($args);
  echo $html;
}
function fu_ebay_globalid_callback($args)
{
  global $ebay_globalid_logos;
  echo fu_ebay_addformselect_arr($args, array_keys($ebay_globalid_logos));
}

function fu_ebay_sortorder_callback($args)
{
  global $ebay_sort_order;
  echo fu_ebay_addformselect_dict($args, $ebay_sort_order);

}
function fu_ebay_slideshowstyle_callback($args)
{
  global $fu_ebay_slideshow_styles;
  echo fu_ebay_addformselect_arr($args, $fu_ebay_slideshow_styles);
}

function fu_ebay_deferredloading_callback($args)
{
  global $fu_deferred_loading_options;
  echo fu_ebay_addformselect_dict($args, $fu_deferred_loading_options);
}

function fu_ebay_arrangement_callback($args)
{
  $options = array(
    __("Picture centred, title below", "fast-ebay-listings") => 0,
    __("Title above, picture centred", "fast-ebay-listings") => fuEbayArrangement::TitleTop,
    __("Picture left, title right", "fast-ebay-listings") => fuEbayArrangement::ImageLeft,
    __("Title above, picture left", "fast-ebay-listings") => fuEbayArrangement::TitleTop | fuEbayArrangement::ImageLeft,
  );

  $thumbs = array(
    'fubaby_ebayDefArrangementItem' => 'apples.jpg',
    'fubaby_ebayDefArrangementList' => 'bananas.jpg',
    'fubaby_ebayDefArrangementWidget' => 'oranges.jpg',
  );
  
  // create a mock up listing.
  $ebayItem = new fuEbayListing;
  $ebayItem->Title = "Title Title Title Title";
  $ebayItem->EndTime = "Tomorrow";
  $ebayItem->PriceConv = 100.00;
  $ebayItem->GallerySmall = plugins_url(basename(__DIR__) . "/images/" . $thumbs[$args['id']]);
  $ebayItem->PicLarge = $ebayItem->GallerySmall;
  $ebayItem->PicHuge = $ebayItem->GallerySmall;
  $ebayItem->Active = true;
  $ebayItem->Auction = true;
  $ebayItem->Currency = "&pound;";
  $ebayItem->StoreName = "ACME Co.";

  $html = "";
  $html .= fu_ebay_addformlabel($args);
  
  // First loop to display mock up listing per arrangement option.
  $html .= "<div class=\"fu_ebay_results\"><div class=\"fu_ebay_results_row\">";
  foreach ($options as $key => $value)
  {
    $ebayItem->Arrangement = $value;
    // JS call on listing links to select correct radio button.
    $ebayItem->Url = esc_attr("javascript:document.getElementById(\"{$args['id']}_{$value}\").checked = true;");
    $html .= "<div class=\"fu_ebay_results_cell\" style=\"padding: 10px 20px 10px 0px;\">";
    $html .= $ebayItem->GetListingAsHtml(80, 
        fuEbayShow::Frame | fuEbayShow::Title | fuEbayShow::Image | fuEbayShow::Price | fuEbayShow::Store | fuEbayShow::Time);
    $html .= "</div>";
  }
  // Second loop of radio form controls per arrangement option.
  $html .= "</div><div class=\"fu_ebay_results_row\" style=\"padding: 20px\">";
  foreach ($options as $key => $value)
  {
    $html .= "<div class=\"fu_ebay_results_cell\" ><input type=\"radio\" id=\"{$args['id']}_{$value}\" name=\"{$args['id']}\" value=\"{$value}\"";
    if (get_option($args['id']) == $value)
      $html .= ' checked';
    $html .= "><label for=\"{$args['id']}_{$value}\">{$key}</label></div>";
  }
  $html .= "</div></div>";

  echo $html;
}

function fu_ebay_addformselect_arr($args, $arr)
{
  $html = '<select id="'.$args['id'].'" name="'.$args['id'].'" >';
  foreach ($arr as $value)
  {
    $html .= '<option value="'.esc_attr($value).'"';
    if (get_option($args['id']) == $value)
      $html .= ' selected';
      $html .= '>'.$value.'</option>';
  }
  $html .= '</select>';
  $html .= fu_ebay_addformlabel($args);
  return $html;
}

function fu_ebay_addformselect_dict($args, $dict)
{
  $html = '<select id="'.$args['id'].'" name="'.$args['id'].'" >';
  foreach ($dict as $value => $desc)
  {
    $html .= '<option value="'.esc_attr($value).'"';
    if (get_option($args['id']) == $value)
      $html .= ' selected';
      $html .= '>'.$desc.'</option>';
  }
  $html .= '</select>';
  $html .= fu_ebay_addformlabel($args);
  return $html;
}

function fu_ebay_addformlabel($args) : string
{
  if (isset($args['label']) && !empty($args['label'])) 
    return'<p><label for="'.$args['id'].'"> '  . $args['label'] . '</label></p>';
  return "";
}

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Handle per user eBay seller id.

add_action( 'show_user_profile', 'fu_ebaypro_show_profile_fields' );
add_action( 'edit_user_profile', 'fu_ebaypro_show_profile_fields' );

function fu_ebaypro_show_profile_fields( $user )
{
  ?>
	<h3><?php _e('eBay Information', 'fast-ebay-listings'); ?></h3>
	<table class="form-table">
		<tr>
			<th><label for="ebayuserid">eBay User</label></th>
			<td>
				<input type="text" name="ebayuserid" id="ebayuserid" value="<?php echo esc_attr( get_the_author_meta( 'ebayuserid', $user->ID ) ); ?>" class="regular-text" /><br />
				<span class="description">Enter your eBay username. Used for ebay searches by post 'author' as seller.</span>
			</td>
		</tr>
	</table>
<?php 
}


add_action( 'personal_options_update', 'fu_ebaypro_save_profile_fields' );
add_action( 'edit_user_profile_update', 'fu_ebaypro_save_profile_fields' );

function fu_ebaypro_save_profile_fields( $user_id )
{
  if ( !current_user_can( 'edit_user', $user_id ) )
    return false;
  update_user_meta( $user_id, 'ebayuserid', $_POST['ebayuserid'] );
}


?>