<?php

//////////////////////////////////////////////////////////////////////////
//
// Class to query the eBay Browse Get Item
//
//////////////////////////////////////////////////////////////////////////

require_once __DIR__."/apicall.php";

class fuEbayBrowseGetItemApiCall extends fuEbayApiCall
{  
  public $item;
  
  function __construct($item) 
  {
    parent::__construct();
    $this->item = $item;
    $this->arrangement = get_option('fubaby_ebayDefArrangementItem', 'None');
  }

  protected function constructRequest()
  {
    $this->requestUri = $this->getEndpoint() . "item?id={$this->item}";
    parent::constructRequest();
  }

  protected function createListingGrid($resp)
  {
    if ($resp != null && isset($resp->itemId)) 
    {
      $this->resultCount = 1;
      $ebayItem = $this->initEbayListing($resp);
      $this->result .= $ebayItem->GetListingAsHtml($this->picWidth, $this->show);
    }
    else 
    {
      $this->result .= get_option('fubaby_ebayEmptySearchMsg');
    }
  }

  protected function initEbayListing($item)
  {
    global $ebay_globalid_currencies;
    
    $ebayItem = $this->createEbayListing();
    $ebayItem->Currency = $ebay_globalid_currencies[$this->globalId];
    $ebayItem->Arrangement = $this->arrangement;

    $ebayItem->ItemId = (string)$item->itemId;
    $ebayItem->Title = (string)$item->title;
    $ebayItem->Url = (string)$item->itemAffiliateWebUrl;
    $ebayItem->PicHuge = $ebayItem->PicLarge = (string)$item->image->imageUrl;
    $ebayItem->GallerySmall = (string)$item->image->imageUrl;
    $ebayItem->AuctionBids = isset($item->bidCount) ? (int)$item->bidCount : 0;
    $ebayItem->EndTime = (string)$item->itemEndDate;
    $ebayItem->Active = strtotime($ebayItem->EndTime) > time();

    $ebayItem->Location = isset($item->itemLocation->city) ? "{$item->itemLocation->city}, {$item->itemLocation->country}" : $item->itemLocation->country;
    $ebayItem->Feedback = (int)$item->seller->feedbackScore;
    $ebayItem->FeedbackPercent = isset($item->seller->feedbackPercentage) ? intval($item->seller->feedbackPercentage) : 100;
  
    if (in_array("AUCTION", $item->buyingOptions))
    {
      $ebayItem->Price = $item->currentBidPrice->value;
      $ebayItem->PriceConv = $item->currentBidPrice->value;

      if (in_array("FIXED_PRICE", $item->buyingOptions))
      {
        $ebayItem->PriceBIN = $item->price->value;
        $ebayItem->PriceBINConv = $item->price->value;
        $ebayItem->ListingType = "AuctionWithBIN"; // Auction + Fixed price = AuctionWithBIN
      }
      else
        $ebayItem->ListingType = "Auction";
    }
    
    // Auctions with BIN/Best Offers
    if (in_array("FIXED_PRICE", $item->buyingOptions) && !in_array("AUCTION", $item->buyingOptions))
    {
      $ebayItem->Price = $ebayItem->PriceBIN = $item->price->value;
      $ebayItem->PriceConv = $ebayItem->PriceBINConv = $item->price->value;
      $ebayItem->ListingType = "FixedPrice";
    }
    
    if (in_array("BEST_OFFER", $item->buyingOptions))
      $ebayItem->BINBestOffer = true;
     
    if ($item->seller->sellerAccountType == "BUSINESS" && isset($item->seller->username))
      $ebayItem->StoreName = (string)$item->seller->username;
    
    return $ebayItem;
  }
  
  protected function createDeferredLoadingStub()
  {
    $stubId = "fu_ebay_" . parent::$id++;

    $this->result = '
    <div id="'.$stubId.'">Loading....</div>
    <script>
    var $content'.$stubId.' = jQuery("#'.$stubId.'");
    jQuery(document).load(jQuery.ajax({
      type : "post",
      url : "'.admin_url('admin-ajax.php').'",
      data : {
          action : "fu_ebay_load_getitem",
          fu_ebay_item : "'.$this->item.'",
          fu_ebay_picwidth : "'.$this->picWidth.'",
          fu_ebay_customId : "'.$this->customId.'",
          nonce : "'.wp_create_nonce("shortcode-getitem").'",
      },
      success : function( response ) {
          $content'.$stubId.'.html( response );
      },
      error: function(e) {
        console.log(e);
      }
    }));
    </script>
    ';

  }

  protected function validateArgs()
  {
    parent::validateArgs();
    if ($this->picWidth <= 0) 
      $this->picWidth = get_option('fubaby_ebayPicWidthItem');	
    
    $this->item = intval($this->item);
    if ($this->item == 0)
      return false;
    
    return true;
  }    
}

// Main AJAX entry function
function fu_ebay_load_getitem() 
{
  if (!check_ajax_referer('shortcode-getitem', 'nonce', false)) 
  {
    $this->errorLog('Nonce check failed');
    die;
  }

  $apicall = new fuEbayBrowseGetItemApiCall($_POST['fu_ebay_item']);
  if (isset($_POST['fu_ebay_picwidth'])) $apicall->picWidth = $_POST['fu_ebay_picwidth'];
  if (isset($_POST['fu_ebay_customId'])) $apicall->customId = $_POST['fu_ebay_customId'];
  echo $apicall->call(true);
  die();
}

add_action( 'wp_ajax_fu_ebay_load_getitem', 'fu_ebay_load_getitem' );
add_action( 'wp_ajax_nopriv_fu_ebay_load_getitem', 'fu_ebay_load_getitem' );