<?php
/**
 * Functions to register client-side assets (scripts and stylesheets) for the
 * Gutenberg block.
 *
 * @package fast-ebay-listings-pro
 */

/**
 * Define render callback. 
 *
 */
function fuEbayItemRenderCallback($atts)
{
  // Attributes
  extract(shortcode_atts(array(
      'item' => '',
      'picwidth' => -1,
      'customid' => ''
  ), $atts));

  $apicall = new fuEbayBrowseGetItemApiCall($item);
  $apicall->picWidth = $picwidth;
  $apicall->customId = $customid;
  return $apicall->call();
}


/**
 * Registers all block assets so that they can be enqueued through Gutenberg in
 * the corresponding context.
 *
 * @see https://wordpress.org/gutenberg/handbook/blocks/writing-your-first-block-type/#enqueuing-block-scripts
 */
function fu_ebay_item_block_init() 
{
	// Skip block registration if Gutenberg is not enabled/merged.
	if ( ! function_exists( 'register_block_type' ) ) {
		return;
	}
	$dir = dirname( __FILE__ );

	$index_js = 'item.js';
	wp_register_script(
		'item-block-editor',
		plugins_url( $index_js, __FILE__ ),
		array(
			'wp-blocks',
		  'wp-i18n',
			'wp-element',
		  'wp-components',
		  'wp-editor'
		),
		filemtime( "$dir/$index_js" )
	);
	
	$editor_css = 'editor.css';
	wp_register_style(
		'item-block-editor',
		plugins_url( $editor_css, __FILE__ ),
		array(),
		filemtime( "$dir/$editor_css" )
	);

	register_block_type( 'fast-ebay-listings/item', array(
		'editor_script' => 'item-block-editor',
		'editor_style'  => 'item-block-editor',
		'style'         => 'item-block',
	  'render_callback' => 'fuEbayItemRenderCallback'
	) );
}
add_action( 'init', 'fu_ebay_item_block_init' );
