<?php
/**
 * Functions to register client-side assets (scripts and stylesheets) for the
 * Gutenberg block.
 *
 * @package fast-ebay-listings-pro
 */

/**
 * Define render callback. 
 *
 */
function fuEbaySearchRenderCallback($atts){
  // Attributes
  extract(shortcode_atts(array(
      'title' => '',
      'category' => 0,
      'query' => '',
      'seller' => '',
      'columns' => -1,
      'rows' => -1,
      'picwidth' => -1,
      'minprice' => -1,
      'maxprice' => -1,
      'aspectname' => "",
      'aspectvalue' => "",
      'sort' => '',
      'customid' => '',
      'slideshow' => -1,
      'slides' => -1
  ), $atts));

  $apicall = new fuEbayBrowseSearchApiCall($title);
  $apicall->picWidth = $picwidth;
  $apicall->customId = $customid;

	$apicall->setQuery($query);
  $apicall->setCategories($category);
  $apicall->setSellers($seller);
  $apicall->setAspect($aspectname, $aspectvalue);
  $apicall->setTableSize($columns, $rows);
  $apicall->minPrice = $minprice;
  $apicall->maxPrice = $maxprice;
  $apicall->setSlideShow($slideshow, $slides);
  $apicall->setSortOrder($sort);
  return $apicall->call();
}


/**
 * Registers all block assets so that they can be enqueued through Gutenberg in
 * the corresponding context.
 *
 * @see https://wordpress.org/gutenberg/handbook/blocks/writing-your-first-block-type/#enqueuing-block-scripts
 */
function fu_ebay_search_block_init() {
	// Skip block registration if Gutenberg is not enabled/merged.
	if ( ! function_exists( 'register_block_type' ) ) {
		return;
	}
	$dir = dirname( __FILE__ );

	$index_js = 'search.js';
	wp_register_script(
		'search-block-editor',
		plugins_url( $index_js, __FILE__ ),
		array(
			'wp-blocks',
		  'wp-i18n',
			'wp-element',
		  'wp-components',
		  'wp-editor'
		),
		filemtime( "$dir/$index_js" )
	);

	wp_localize_script('search-block-editor', 'fuScript', array(
		'pluginsUrl' => plugins_url('', __FILE__) . '/../',
	));
	
	$editor_css = 'editor.css';
	wp_register_style(
		'search-block-editor',
		plugins_url( $editor_css, __FILE__ ),
		array(),
		filemtime( "$dir/$editor_css" )
	);

	register_block_type( 'fast-ebay-listings/search', array(
		'editor_script' => 'search-block-editor',
		'editor_style'  => 'search-block-editor',
		'style'         => 'search-block',
	  'render_callback' => 'fuEbaySearchRenderCallback'
	) );
}
add_action( 'init', 'fu_ebay_search_block_init' );
