<?php
//////////////////////////////////////////////////////////////////////////
//
// Class to store a single ebay listing
//
//////////////////////////////////////////////////////////////////////////

require_once __DIR__."/utilities.php";

// Constants to define what data to show when printing out.
class fuEbayShow
{
  const Frame = 1;
  const Title = 2;
  const Image = 4;
  const Price = 8;
  const Time = 16;
  const Feedback = 32;
  const Location = 64;
  const Seller = 128;
  const Store = 256;
  const EbayLogo = 512;
  const VisitLink = 1024;
  
  const SearchListing = 0x1F;
  const All = 0xFFFF;
}

class fuEbayArrangement
{
  const TitleTop = 1;
  const ImageLeft = 2;
}

class fuEbayListing
{
  const DebugPrintOuts = FALSE;
  
  public function __construct()
  {
    $this->Active = TRUE;
    $this->Sold = FALSE;
    $this->AuctionBids= 0;
    $this->BINBestOffer = FALSE;
    $this->Feedback = 0;
    $this->FeedbackPercent = 100;
  }  

  protected function GetEbayLink($content = '')
  {
    $target = get_option('fubaby_ebayNewWindow', 1) == 1 ?
      "target=\"_blank\"" :
      "";
    
  	if ( $content == '' ) $content = htmlentities($this->Title); 
  	$result = "<a href=\"".htmlentities($this->Url)."\" title=\"".htmlentities($this->Title)."\" rel=\"nofollow\" {$target}>".$content."</a>";
  	return $result;	
  }
  
  protected function GetEbayImage($picWidth)
  {
  	$picWidth = intval($picWidth);
  	if ( $picWidth <= 0 )
  		$picWidth = get_option('fubaby_ebayPicWidth');
  	
    if ($picWidth > 400 && !empty($this->PicHuge))
      $picUrl = $this->PicHuge;
    else if ($picWidth > 140 && !empty($this->PicLarge))
      $picUrl = $this->PicLarge;
    else if ($picWidth > 96 && !empty($this->GalleryLarge))
      $picUrl = $this->GalleryLarge;
    else if ($picWidth > 80 && !empty($this->GalleryMedium))
      $picUrl = $this->GalleryMedium;
    else
      $picUrl = $this->GallerySmall;
  	
    if (empty($picUrl))
      return "";
        
  	$result = "<img src=\"" . htmlentities(fuEbayUtils::GetSecureUrl($picUrl)) . "\" ";
  	$result .= "width=\"". $picWidth . "\" ";
  	$result .= "alt=\"" . htmlentities($this->Title) . "\" ";
  	$result .= "title=\"" . htmlentities($this->Title) . "\" ";
  	$result .= "/>";
  	
  	return $this->GetEbayLink($result);
  }
  
  protected function GetEndTime()
  {
  	// get time difference in seconds.
  	$dateEnd = strtotime($this->EndTime);
    $diff = $dateEnd - time();
    
    $days = floor($diff / (60*60*24));
    $hours = floor(($diff - ($days*60*60*24)) / (60*60));
    $mins = floor(($diff - ($days*60*60*24) - ($hours*60*60)) / 60);
    
    if ( $diff > 60 )
    {
      $result = "Ends in ";
    	if ($days > 0) $result .= $days . "d ";
    	if ($hours > 0) $result .= $hours . "h ";
      if ($days == 0 && $mins > 0) $result .= $mins . "m ";
      return $result;
    }
    else if ( $diff >= 0 )
      return "Ends in {$diff}s ";
    else
      return "Ended: " . date("F j, Y, g:i a", $dateEnd);
  }
  
 
  //! Func to write out a listing. 
  public function GetListingAsHtml($picWidth, $show)
  { 
    $results = "";
    
    // Frame and title.
		if ( $show & fuEbayShow::Frame )
    {
			$results .= "<div class=\"fu_ebay_listing_frame\">\n";
    }
     
    $results .= "<div class=\"fu_ebay_listing_item\">\n";
    
    // Top Title
    if ( $show & fuEbayShow::Title && $this->Arrangement & fuEbayArrangement::TitleTop )		
      $results .= "<div class=\"fu_ebay_title\">" . $this->GetEbayLink() ."</div>\n";

    if ( $this->Arrangement & fuEbayArrangement::ImageLeft )
      $results .= $this->GetListingLeftImage($picWidth, $show);
    else
      $results .= $this->GetListingCentreImage($picWidth, $show);

    if ( $show & fuEbayShow::VisitLink )
      $results .= "<div class=\"fu_ebay_visitlink\">" . $this->GetEbayLink("View Details") . "</div>\n";

    $results .= "</div>\n"; //fu_ebay_listing_item

    if ( $show & fuEbayShow::Frame )
      $results .= "</div>"; // fu_ebay_listing_frame
           
    return $results;
  }	
  
  protected function GetListingCentreImage($picWidth, $show)
  { 
    $results = "<div class=\"fu_ebay_listing_contentwrapper_centre\">\n";   
    
    // Not left image.
    if ( $show & fuEbayShow::Image )
    {
      $results .= "<div class=\"fu_ebay_listing_img\" style=\"height:" . $picWidth . "px\">\n" . 
        $this->GetEbayImage($picWidth) . 
        "\n</div>\n";
    }
    
    // Content box.
    $results .= "<div class=\"fu_ebay_listing_content_centre\">";
    
    $results .= $this->GetListingContent($picWidth, $show);

    $results .= "</div>\n"; // fu_ebay_listing_content_centre
    
    $results .= "</div>\n"; // fu_ebay_listing_contentwrapper_centre
    
    // Image
    if ( $show & fuEbayShow::Image && $this->Arrangement & fuEbayArrangement::ImageLeft )
      $results .= "<div class=\"fu_ebay_listing_img_left\" style=\"width: " . $picWidth . "px\">" . $this->GetEbayImage($picWidth) . "</div>\n";
          
    $results .= "<div class=\"fu_ebay_listing_clear\"></div>\n";
    
    return $results;
  }

  protected function GetListingLeftImage($picWidth, $show)
  { 
    global $ebay_globalid_currencies;
    
    $results = "";
    $results .= "<div class=\"fu_ebay_listing_contentwrapper_left\">\n";   
    
    // Not left image.
    if ( $show & fuEbayShow::Image && ($this->Arrangement & fuEbayArrangement::ImageLeft) == 0 )
    {
      $results .= "<div class=\"fu_ebay_listing_img\" style=\"height:" . $picWidth . "px\">\n" . 
        $this->GetEbayImage($picWidth) . 
        "\n</div>\n";
    }
    
    // Content box.
    $results .= sprintf("<div class=\"fu_ebay_listing_content_left\" %s>\n",
      $this->Arrangement & fuEbayArrangement::ImageLeft ? "style=\"margin-left: {$picWidth}px;\"" : "");
    
    $results .= $this->GetListingContent($picWidth, $show);

    $results .= "</div>\n"; // fu_ebay_listing_content_left
    
    $results .= "</div>\n"; // fu_ebay_listing_contentwrapper_left
    
    // Image
    if ( $show & fuEbayShow::Image)
      $results .= "<div class=\"fu_ebay_listing_img_left\" style=\"width: " . $picWidth . "px\">" . $this->GetEbayImage($picWidth) . "</div>\n";
          
    $results .= "<div class=\"fu_ebay_listing_clear\"></div>\n";
    

    return $results;
  }

  protected function GetListingContent($picWidth, $show)
  { 
    global $ebay_globalid_currencies;
    $results = "";

    if ( $show & fuEbayShow::EbayLogo )
      $results .= fuEbayUtils::GetRightNowLogoHtml($this->Url);
    
    // Not top title
    if ( $show & fuEbayShow::Title && ($this->Arrangement & fuEbayArrangement::TitleTop) == 0 )		
      $results .= "<div class=\"fu_ebay_title\">\n" . $this->GetEbayLink() ."\n</div>\n";
    
    // StoreName
    if ( $show & fuEbayShow::Store && !empty($this->StoreName) )
      $results .= "<div class=\"fu_ebay_storename\">Shop: {$this->StoreName}</div>\n";    
      
    // Price
    if ( $show & fuEbayShow::Price )
    {
      $priceStatus = "fu_ebay_priceactive";
      if ( !$this->Active ) 
      {
        $priceStatus = $this->Sold ? "fu_ebay_pricesold" : "fu_ebay_priceunsold";
      }			
      
      $results .= "<div class=\"{$priceStatus}\">{$this->Currency}{$this->PriceConv}</div>\n";
      
      // Fixed Sale/Shop BIN images.
      if ( $this->ListingType == "FixedPrice" || $this->ListingType == "StoreInventory" )
      {
        $results .= $this->BINBestOffer ? fuEbayUtils::GetBINBestOfferLogoHtml() : fuEbayUtils::GetBINLogoHtml();
      }
      
      // Fixed Sale/Shop BIN images.
      if ( $this->ListingType == "Classified" )
      {
        $results .= "&nbsp;<div class=\"fu_ebay_classifiedtext\">Classified&nbsp;Ad</div>\n";
      }
      
      // Bids
      if ( $this->ListingType == "Auction" || $this->ListingType == "AuctionWithBIN" )
        $results .= "&nbsp;<div class=\"fu_ebay_bids\">(" . $this->AuctionBids . ($this->AuctionBids == 1 ? " bid" : " bids") . ")</div>\n";
      

      if ( $this->Sold )
        $results .= "&nbsp;<div class=\"fu_ebay_soldtext\">Sold</div>\n";
              
      // Auctions with an additional BIN price.
      if ( $this->ListingType == "AuctionWithBIN" )
      {
        $results .= $this->BINBestOffer ? fuEbayUtils::GetBINBestOfferLogoHtml() : fuEbayUtils::GetBINLogoHtml();
        $results .= "\n<div class=\"fu_ebay_pricebin\">";
        $results .= " for {$this->Currency}{$this->PriceBINConv}";
        $results .= "</div>\n";
      }
    }
    
    // Seller .
  //   if ( $show & fuEbayShow::Seller )
  //     $results .= "Seller: " . intval($this->) . " (" . $this->FeedbackPercent . "%) <br/>\n";
    
    // Seller feedback.
    if ( $show & fuEbayShow::Feedback )
      $results .= "<div class=\"fu_ebay_feedback\">Seller Feedback: " . intval($this->Feedback) . " (" . $this->FeedbackPercent . "%)</div>\n";
    
    // Auction End Time.
    if ( $show & fuEbayShow::Time && $this->EndTime != null)
      $results .= "<div class=\"fu_ebay_endtime\">" . $this->GetEndTime() . "</div>\n";
    
    // Location
    if ( $show & fuEbayShow::Location )
      $results .= "<div class=\"fu_ebay_location\">Location: " . $this->Location . "</div>\n";

    return $results;
  }

  // Class Properties.
  public $Arrangement = 0;
    
  public $ItemId;			//!< Listing ProductID
  public $ListingType; //!< Listing type.
  public $Title;     //!< Listing title
  public $Url;       //!< Listing URL
  public $Active;    //!< Listing active or completed.
  public $PicHuge;   //!< Large Picture (>800px)
  public $PicLarge;  //!< Large Picture (>400px)
  public $GalleryLarge;  //!< Large gallery picture (140px)
  public $GalleryMedium;  //!< Medium gallery picture (96px)
  public $GallerySmall;  //!< Small gallery picture (80px)
  
  public $StoreName;  //!< Name of ebay store with listing.
  
  public $Currency;      //!< Currency of listing.
  public $Price;         //!< Price of listing in above currency
  public $PriceConv;     //!< Price of listing converted to global currency.
  public $PriceBIN;      //!< Buy It Now price of listing.
  public $PriceBINConv;  //!< Buy It Now price converted to global currency.
  public $Sold;          //!< For completed listings, whether item sold or not.
  
  public $Auction;
  public $AuctionBids;
  public $BIN;
  public $BINBestOffer;
  
  public $EndTime;       //! Listing end time.
  public $Location;      //!< Sellers location.
  public $Feedback;          //!< Sellers feedback score.
  public $FeedbackPercent;   //!< Percentage of positive feedback.
  
}
