<?php

//////////////////////////////////////////////////////////////////////////
//
// Trait to handle presentation of apicall results
//
//////////////////////////////////////////////////////////////////////////

$fuEbayTableSlideId = 0;

trait fuEbayTable
{
  private $limit = -1;
  public $columns = 1;
  public $rows = 1;
  
  private $slideLimit = -1;
  public $slideShow = "None";
  public $slides;
  
  private $nItems;
  private $nSlides;
  
  public function setTableSize($columns, $rows)
  {
    $this->columns = intval($columns);
    if ($this->columns < 1) $this->columns = get_option('fubaby_ebayDefColumns');
    if ($this->columns < 1) $this->columns = 1;
    
    $this->rows = intval($rows);
    if ($this->rows < 1) $this->rows = get_option('fubaby_ebayDefRows');
    if ($this->rows < 1) $this->rows = 1;
    
    // Calculate a slideLimit value from 
    if ($this->rows > 0) $this->slideLimit = $this->columns * $this->rows;
    else $this->slideLimit = $this->columns;  
  }
  
  public function setSlideShow($slideShow, $slides = -1)
  {
    $this->slideShow = strtolower($slideShow);
    $this->slides = intval($slides);
    if ($this->slides <= 0) $this->slides = get_option('fubaby_ebayDefNumSlides');
    
    if ($this->slideShow == "1" || 
        stristr($this->slideShow, "true") !== false ||
        stristr($this->slideShow, "default") !== false)
      $this->slideShow = get_option('fubaby_ebayDefSlideshowStyle');

    // If no slideShow, no point having limit beyond what we'll present 
    switch ($this->slideShow)
    {
      case -1:
      case "none":
      case false:
        $this->slides = 1;
        if ($this->limit > $this->columns * $this->rows)
          $this->limit = $this->columns * $this->rows;
        break;
      default:
        if ($this->slides > 0)
          $this->limit = $this->columns * $this->rows * $this->slides;
    }
  }
  
  public function validate()
  {
    if ($this->columns < 1) $this->columns = get_option('fubaby_ebayDefColumns');
    if ($this->columns < 1) $this->columns = 1;    
    if ($this->rows < 1) $this->rows = get_option('fubaby_ebayDefRows');
    if ($this->rows < 1) $this->rows = 1;
    
    if ($this->limit < 1)
      $this->limit = $this->columns * $this->rows;
    
    // Ensure we have a valid slide limit, should be multiple of columns.
    $this->slideLimit = intval($this->slideLimit);
    if ($this->slideLimit < 1) $this->slideLimit = $this->columns;
    if (($this->slideLimit % $this->columns) > 0) $this->slideLimit += $this->columns - ($this->slideLimit % $this->columns);
    if ($this->slideLimit == $this->limit) $this->slideShow = "none";
  }
  
  public function genTableStart($searchUrl)
  {
    $searchUrl = htmlEntities($searchUrl);
    $this->nItems = 0;
    $this->nSlides = 0;
    
    // Start table.
    $this->result .= "<div class=\"fu_ebay_results_container\">\r\n";
    $this->result .= "<div class=\"fu_ebay_results_title\">\r\n";
    $this->result .= fuEbayUtils::GetRightNowLogoHtml($searchUrl);
    if ( $this->title != "" )
    {
      $target = get_option('fubaby_ebayNewWindow', 1) == 1 ?
        "target=\"_blank\"" :
        "";
      
      $this->result .= "<a href=\"{$searchUrl}\" rel=\"nofollow\" {$target}>{$this->title}</a>\r\n";
    }
    $this->result .= "</div>\r\n"; // fu_ebay_results_title
  }

  public function genTableItem($itemHtml)
  {
    global $fuEbayTableSlideId;
    $slideShowClasses = strtolower($this->slideShow) != "none" ? " fu_ebay_slide_{$fuEbayTableSlideId} fu_ebay_slidefade" : "";
    
    if ($this->slideShow != "none")
    {
      $itemHtml = str_replace("class=\"fu_ebay_title\"", "class=\"fu_ebay_title fu_ebay_maxtwolines\"", $itemHtml);
    }
    
    if (($this->nItems % $this->slideLimit) == 0 )
    {
      $this->result .= "<div class=\"fu_ebay_results{$slideShowClasses}\">\r\n";
    }
    
    if (($this->nItems % $this->columns) == 0)
    {
      $this->result .= "<div class=\"fu_ebay_results_row\">\r\n";
    }
  
    $this->result .= "<div class=\"fu_ebay_results_cell\" >\r\n";
    $this->result .= $itemHtml;
    $this->result .=  "\r\n</div>\r\n";
  
    ++$this->nItems;
  
    if (($this->nItems % $this->columns) == 0)
    {
      $this->result .= "</div>\r\n"; // fu_ebay_results_row
    }
    
    if (($this->nItems % $this->slideLimit) == 0)
    {
      $this->result .= "</div> <!-- .fu_ebay_results -->\r\n"; // fu_ebay_results
      ++$this->nSlides;
    }
  }
  
  public function genTableEnd()
  {
    global $fuEbayTableSlideId;
    // Close last row if needed.
    if (($this->nItems % $this->columns) != 0)
    {
      $this->result .= "</div>\r\n"; // fu_ebay_results_row
    }
  
    if (($this->nItems % $this->slideLimit) != 0)
    {
      $this->result .= "</div> <!-- .fu_ebay_results -->\r\n"; // fu_ebay_results
    }

    $this->genSlideshowDots(); 
    $this->result .= "</div>\r\n"; // fu_ebay_results_container
    
    ++$fuEbayTableSlideId;
  }  
  
  public function limitHit()
  {
    return $this->nItems >= $this->limit;
  }
  
 
  private function genSlideshowDots()
  {
    global $fuEbayTableSlideId;
    // Slideshow dots along bottom
    if (strtolower($this->slideShow) != "none" && $this->nSlides > 1)
    {
      $this->result .= "<script type=\"text/javascript\">fu_ebay_slideIndex[$fuEbayTableSlideId] = 0;</script>";
      $this->result .= "<div style=\"text-align:center\">";
      $this->result .= "<span class=\"fu_ebay_slideprev\" onclick=\"plusSlides(-1, $fuEbayTableSlideId)\">&#10094;</span>";
      for ($i=0; $i<$this->nSlides; ++$i)
      {
        $this->result .= "<span class=\"fu_ebay_slidedot fu_ebay_slidedot_$fuEbayTableSlideId\" onclick=\"currentSlide($i, $fuEbayTableSlideId)\"></span>";
      }
      $this->result .= "<span class=\"fu_ebay_slidenext\" onclick=\"plusSlides(1, $fuEbayTableSlideId)\">&#10095;</span>";
      
      $this->result .= "</div>";
      $this->result .= "<script type=\"text/javascript\">showSlide(0, $fuEbayTableSlideId);</script>";

      
      if (strtolower($this->slideShow) == "auto")
        $this->result .= "<script type=\"text/javascript\">autoShowSlide($fuEbayTableSlideId);</script>";

    }
  }  
}