<?php
//////////////////////////////////////////////////////////////////////////
//
// Class with general utility funcs
//
//////////////////////////////////////////////////////////////////////////

require_once __DIR__."/constants.php";

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Add CSS styles to header.

add_action('wp_print_styles', 'fu_ebay_addstyles');

function fu_ebay_addstyles() 
{
  $myStyleFile = WP_PLUGIN_DIR . '/' . basename(__DIR__) . '/styles.css';
  if ( file_exists($myStyleFile) ) 
  {
    $styleContents = file_get_contents($myStyleFile);
    wp_register_style('fu_ebay_style', '');
    wp_enqueue_style( 'fu_ebay_style');
    wp_add_inline_style('fu_ebay_style', $styleContents);
  }
}

add_action('admin_head', 'fu_ebay_addadminstyles');

function fu_ebay_addadminstyles() 
{
  $myStyleUrl = plugins_url(basename(__DIR__) . '/styles.css');
  echo '<link rel="stylesheet" href="'.$myStyleUrl.'" type="text/css" media="all" />';
  echo '<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.0.13/css/all.css" integrity="sha384-DNOHZ68U8hZfKXOrtjWvjxusGo9WQnrNx2sqG0tfsghAvtVlRW3tvkXWZh58N9jp" crossorigin="anonymous">';
}

////////////////////////////////////////////////////////////////////////////////////////////////////////
// Add JS scripts to header.

add_action('wp_enqueue_scripts', 'fu_ebay_addscripts');
add_action( 'admin_enqueue_scripts', 'fu_ebay_addscripts');

function fu_ebay_addscripts() 
{
  $myScriptFile = WP_PLUGIN_DIR . '/' . basename(__DIR__) . '/script.js';
  if ( file_exists($myScriptFile) ) 
  {
    if (!wp_script_is('jquery', 'done'))
    wp_enqueue_script( 'jquery' );
 
    wp_add_inline_script( 'jquery-migrate', 'jQuery(document).ready(function(){});' );    
    $scriptContents = file_get_contents($myScriptFile);

    $scriptContents .= "var fu_ebay_adminurl = \"" . admin_url('admin-ajax.php') . "\";\n";
    $scriptContents .= "var fu_ebay_adminsearchnonce = \"" . wp_create_nonce("shortcode-search") . "\";\n";

    wp_register_script('fu_ebay_script', '');
    wp_enqueue_script('fu_ebay_script');	
    wp_add_inline_script('fu_ebay_script', $scriptContents, 'after');
  }
}


////////////////////////////////////////////////////////////////////////////////////////////////////////
// Other utility methods

class fuEbayUtils
{
  public static function GetRightNowLogoHtml($url = "http://www.ebay.com")
  {
    global $ebay_globalid_logos;
    $globalid = get_option('fubaby_ebayGlobalID');
    $logoUrl = plugins_url(basename(__DIR__) .  $ebay_globalid_logos[$globalid]);
    
    $target = get_option('fubaby_ebayNewWindow', 1) == 1 ?
      "target=\"_blank\"" :
      "";
    
    $result = "<a href=\"{$url}\" rel=\"nofollow\" {$target}>";
    $result .= "<img src=\"{$logoUrl}\" style=\"border: 0;\" width=\"108\" height=\"45\" alt=\"Right Now on eBay\"/>";
    $result .= "</a>";
    return $result;
  }
  
  public static function GetBINLogoHtml()
  {
    $logoUrl = plugins_url(basename(__DIR__) .  FUBABY_EBAY_BINLOGOIMG);
    return " <img src=\"{$logoUrl}\" style=\"border: 0;\" width=\"54\" height=\"15\" alt=\"Buy it Now\"/>";   
  }
  
  public static function GetBINBestOfferLogoHtml()
  {
    $logoUrl = plugins_url(basename(__DIR__) .  FUBABY_EBAY_BINBOLOGOIMG);
    return " <img src=\"{$logoUrl}\" style=\"border: 0;\" width=\"70\" height=\"20\" alt=\"Buy it Now or Best Offer\"/>";   
  }
  
  public static function GetSecureUrl($url)
  {
    if (is_ssl())
      return str_replace("http://", "https://", $url);
    else 
      return $url;
  }
  
}

// https://www.php.net/manual/en/function.is-countable
if (! function_exists('is_countable')) {
  /**
    * @param mixed $value The value to check
    * @return bool
    */
  function is_countable($value): bool
  {
      return is_array($value) || (is_object($value) && $value instanceof Countable);
  }
}